<?php
/**
 * Plugin Name:       ELEX WooCommerce Discount Per Payment Method
 * Plugin URI:        https://elextensions.com/plugin/elex-woocommerce-discount-per-payment-method-free/
 * Description:       The plugin allows to set discounts according to the payment method selected on the Checkout page.
 * Version: 1.0.10
 * Author:            ELEXtensions
 * Author URI:        https://elextensions.com/
 * Developer:         ELEXExtension    
 * WC requires at least: 2.6.0
*  WC tested up to: 6.7
 *
 * @package Elex Discount Per Payment Mehtod
 * 
 */

 //Exit if accessed directly.
if (!defined('ABSPATH')) {

	exit;
}

if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true )) {

	add_action(
		'admin_notices',
		function() {
			?>
		<div class="notice notice-error is-dismissible">
			<p>
				<?php
					$allowed_html = array(
						'strong' => array(),
					);
					echo wp_kses( __( '<strong>WooCommerce</strong> plugin must be active for <strong>ELEX WooCommerce Discount Per Payment Method</strong> to work.', 'elex_wfp_discount_per_payment_method' ), $allowed_html );
				?>
			</p>
		</div>
			<?php
		}
	);
	return false;

}
   
if (class_exists('Elex_Woo_Discount_Per_Payment_Method')) {

	add_action(
		'admin_notices',
		function() {
			?>
		<div class="notice notice-error is-dismissible">
			<p>
				<?php
					$allowed_html = array(
						'a'      => array(
							'href'  => array(),
							'title' => array(),
						),
						'br'     => array(),
						'em'     => array(),
						'strong' => array(),
					);
					echo wp_kses( __( "You already have the basic version of <strong>ELEX WooCommerce Discount Per Payment Method</strong> installed. Please disable & remove previous basic version before enabling. For any issues, kindly contact our <a target='_blank' href='https://elextensions.com/support/'>support</a>.", 'elex_wfp_discount_per_payment_method' ), $allowed_html );
				?>
			</p>
		</div>
			<?php
		}
	);

	return false;
}


require_once( WP_PLUGIN_DIR . '/woocommerce/includes/admin/settings/class-wc-settings-page.php' );
include_once( ABSPATH . 'wp-admin/includes/plugin.php');


class Elex_Woo_Discount_Per_Payment_Method extends WC_Settings_Page {


	public function __construct () {

					
		//registering and loading scripts
		include('includes/scripts.php');  		
				
		$this->id = 'elex-discount-per-payment-method';
		$this->label = __( 'ELEX Discount Per Payment Method', 'elex_wfp_discount_per_payment_method' );
						
		add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_page' ), 99 );
		add_action( 'woocommerce_sections_' . $this->id, array( $this, 'Elex_Woo_Discount_Per_Payment_Method_Output_Sections' ) );
		add_action( 'woocommerce_settings_' . $this->id, array( $this, 'Elex_Woo_Discount_Per_Payment_Method_Output' ) );
		add_action( 'woocommerce_settings_save_' . $this->id, array( $this, 'Elex_Woo_Discount_Per_Payment_Method_Save' ) );
		add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'Elex_Woo_Discount_Per_Payment_Method_Add_Menu') );
		add_action( 'woocommerce_cart_calculate_fees', array ( $this , 'Elex_Woo_Discount_Per_Payment_Method_Add_Discount' ) );
	}

	public function Elex_Woo_Discount_Per_Payment_Method_Get_Sections() {
						
		$sections = array(
			'' => __( 'General Settings', 'elex_wfp_discount_per_payment_method' ),
			'interested_products' => __( 'ELEX Premium plugins!', 'elex_wfp_discount_per_payment_method' )
			
		);
		return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
					
	}

	public function Elex_Woo_Discount_Per_Payment_Method_Output_Sections() {
		global $current_section;
		$sections = $this->Elex_Woo_Discount_Per_Payment_Method_Get_Sections();
		if ( empty( $sections ) || 1 === count( $sections ) ) {
			return;
		}
		echo '<ul class="subsubsub">';
		$array_keys = array_keys( $sections );
		foreach ( $sections as $id => $label ) {

			echo '<li><a href="' . esc_attr( admin_url( 'admin.php?page=wc-settings&tab=' . $this->id . '&section=' . sanitize_title( $id ) )) . '" class="' . esc_attr( ( $current_section == $id ? '':'interested_products' )) . '">' . esc_html( $label ) . '</a> ' . ( end( $array_keys ) == $id ? '' : '|' ) . ' </li>';
		}
		echo '</ul><br class="clear" />';
	}

	public function Elex_Woo_Discount_Per_Payment_Method_Get_Settings() {
						
		global $current_section;
		$settings = array();

						
		if ( 'interested_products' == $current_section ) {
						   
			$settings = array();
						
		} else {

				$wc_gateways    = new WC_Payment_Gateways();
				$PMD_available  = array();
							
			foreach ( $wc_gateways->get_available_payment_gateways() as $gateway ) {

				$PMD_available[$gateway->id] = $gateway->get_method_title();
				add_option('elex_wfp_discount_per_payment_method_available_' . $gateway->id, 0);
							
			}

			$settings = array(

				'section_title' => array(
					'name'     => __( 'ELEX Discount Per Payment Method', 'elex_wfp_discount_per_payment_method' ),
					'type'     => 'title',
					'desc'     => __('<p>Helps you configure and apply a discount on the Checkout page based on the payment method selected by the customer.</p>'),
					'id'       => 'elex_wfp_discount_per_payment_method_title'
				),
				'section' => array(
					'name' => __( 'Checkout discount label', 'elex_wfp_discount_per_payment_method' ),
					'type' => 'text',
					'placeholder' => __( 'Enter custom discount label', 'elex_wfp_discount_per_payment_method'),
					'desc_tip' => true,
					'css' => 'width:200px',
					'desc' => __( 'Enter the text to be displayed on checkout. The default text is <strong>Payment method discount</strong>.', 'elex_wfp_discount_per_payment_method' ),
					'id'   => 'elex_wfp_discount_per_payment_method_label'
				),

				'section_end' => array(
					'type' => 'sectionend',
					'id' => 'elex_wfp_discount_per_payment_method_end'
				),
								
				);    
					
		}

		return apply_filters( 'woocommerce_get_settings_' . $this->id, $settings );
			
	}

	public function Elex_Woo_Discount_Per_Payment_Method_Output() {

		global $current_section;

		if ( 'interested_products' == $current_section ) {
			wp_enqueue_style( 'elex-bootstrap', plugins_url( '/assets/css/elex-market-styles.css', __FILE__ ), false, true );	
			include_once 'includes/market.php';
					
		} else {


		$wc_gateways      =  new WC_Payment_Gateways();
		$settings = $this->Elex_Woo_Discount_Per_Payment_Method_Get_Settings();
		WC_Admin_Settings::output_fields( $settings );
					   
		$PMD_available  = array();
							
			foreach ( $wc_gateways->get_available_payment_gateways() as $gateway ) {

						$PMD_available[$gateway->id] = $gateway->get_method_title();
							
			}
						include_once 'includes/form-settings-template.php';
		}
	}

	public function Elex_Woo_Discount_Per_Payment_Method_Save() {

		global $current_section;
		$settings = $this->Elex_Woo_Discount_Per_Payment_Method_Get_Settings();
		WC_Admin_Settings::save_fields( $settings );
		
		if (isset($_POST['nounce_verify'])) {
		$verify = wp_verify_nonce( sanitize_text_field( $_POST['nounce_verify']), 'form_data');
		}

		if ( isset( $_POST['elex_discount_per_payment_method_options'] ) && $verify ) {

			$options = array_values(
				$_POST['elex_discount_per_payment_method_options']
			);
			
			array_walk_recursive(
				$options,
				'sanitize_text_field'
			);
			update_option( 'elex_discount_per_payment_method_options', $options);
		} else {
			update_option( 'elex_discount_per_payment_method_options', array() );
		}
		if ( $current_section ) {
			do_action( 'woocommerce_update_options_' . $this->id . '_' . $current_section );
		}
	}

	public function Elex_Woo_Discount_Per_Payment_Method_Add_Discount ( $PWD_cart ) {

		if ( is_admin() && ! defined ( 'DOING_AJAX' ) ) {

			return 0;
		}   
		if (is_cart()) {

			return 0;
		}            

		$PWD_Selected_Payment_id = WC()->session->get('chosen_payment_method');
						
		if ( empty( $PWD_Selected_Payment_id ) ) {

		return 0;

		}
						
		$PWD_subtotal = $PWD_cart->subtotal;

		$PWD_stored_values = get_option( 'elex_discount_per_payment_method_options' );
		$PWD_label_default='Payment method discount';

		$PWD_label=!empty(get_option( 'elex_wfp_discount_per_payment_method_label' ))?get_option( 'elex_wfp_discount_per_payment_method_label' ):$PWD_label_default;

		if (!empty($PWD_stored_values)) {
						
			foreach ($PWD_stored_values as $key=>$value) {
							
				if ($value['id']==$PWD_Selected_Payment_id && 'yes' == $value['checkbox_value']) {
								
					$PWD_discount = $value['value'] * $PWD_subtotal / 100;
								
					$PWD_cart -> add_fee( __($PWD_label, 'elex_wfp_discount_per_payment_method'), number_format(-$PWD_discount, 3));
				}
			}
		}
						

	}


	public function Elex_Woo_Discount_Per_Payment_Method_Add_Menu ( $links ) {

		$plugin_links = array(
			'<a href="' . admin_url('/admin.php?page=wc-settings&tab=elex-discount-per-payment-method') . '">' . __('Settings', 'elex_wfp_discount_per_payment_method') . '</a>',
			'<a href=https://elextensions.com/product-category/plugins/> ' . __('ELEX Premium Plugins', 'elex_wfp_discount_per_payment_method') . '</a>',
		);
		return array_merge($plugin_links, $links);


	}



}

new Elex_Woo_Discount_Per_Payment_Method();
